@@ -1,45 +1,45 @@
-/* Copyright (C) 2014 J.F.Dockes
- *	 This program is free software; you can redistribute it and/or modify
- *	 it under the terms of the GNU General Public License as published by
- *	 the Free Software Foundation; either version 2 of the License, or
- *	 (at your option) any later version.
+/* Copyright (C) 2014-2020 J.F.Dockes
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation; either version 2.1 of the License, or
+ *  (at your option) any later version.
  *
- *	 This program is distributed in the hope that it will be useful,
- *	 but WITHOUT ANY WARRANTY; without even the implied warranty of
- *	 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *	 GNU General Public License for more details.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
  *
- *	 You should have received a copy of the GNU General Public License
- *	 along with this program; if not, write to the
- *	 Free Software Foundation, Inc.,
- *	 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program; if not, write to the
+ *  Free Software Foundation, Inc.,
+ *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
+#include "config.h"
+
 #include "conman.hxx"
 
-#include <upnp/upnp.h>                  // for UPNP_E_SUCCESS, etc
+#include <functional>
+#include <iostream>
+#include <string>
+#include <utility>
+#include <vector>
 
-#include <functional>                   // for _Bind, bind, _1, _2
-#include <iostream>                     // for endl
-#include <map>                          // for _Rb_tree_const_iterator, etc
-#include <string>                       // for string, basic_string
-#include <utility>                      // for pair
-#include <vector>                       // for vector
+#include "libupnpp/log.hxx"
+#include "libupnpp/soaphelp.hxx"
 
-#include "libupnpp/log.hxx"             // for LOGDEB
-#include "libupnpp/soaphelp.hxx"        // for SoapOutgoing, SoapIncoming
-
-#include "upmpd.hxx"                    // for UpMpd
+#include "protocolinfo.hxx"
 
 using namespace std;
 using namespace std::placeholders;
 using namespace UPnPP;
+using namespace UPnPProvider;
 
 static const string sTpCM("urn:schemas-upnp-org:service:ConnectionManager:1");
 static const string sIdCM("urn:upnp-org:serviceId:ConnectionManager");
 
-UpMpdConMan::UpMpdConMan(UpMpd *dev)
-    : UpnpService(sTpCM, sIdCM, dev)
+UpMpdConMan::UpMpdConMan(UpnpDevice *dev)
+    : UpnpService(sTpCM, sIdCM, "ConnectionManager.xml", dev)
 {
     dev->addActionMapping(this,"GetCurrentConnectionIDs", 
                           bind(&UpMpdConMan::getCurrentConnectionIDs, 
@@ -60,7 +60,7 @@ bool UpMpdConMan::getEventData(bool all, std::vector<std::string>& names,
     // we return nothing.
     if (all) {
         names.push_back("SinkProtocolInfo");
-        values.push_back(g_protocolInfo);
+        values.push_back(Protocolinfo::the()->gettext());
     }
     return true;
 }
@@ -96,7 +96,7 @@ int UpMpdConMan::getProtocolInfo(const SoapIncoming& sc, SoapOutgoing& data)
 {
     LOGDEB("UpMpdConMan::getProtocolInfo" << endl);
     data.addarg("Source", "");
-    data.addarg("Sink", g_protocolInfo);
+    data.addarg("Sink", Protocolinfo::the()->gettext());
 
     return UPNP_E_SUCCESS;
 }
