@@ -143,33 +143,23 @@ public:
 static StreamProxy *o_proxy;
 
 StreamProxy::UrlTransReturn translateurl(
-    CDPluginServices *cdsrv,
-    const std::string& useragent,
-    std::string& url,
-    const std::unordered_map<std::string, std::string>& querymap,
-    std::unique_ptr<NetFetch>& fetcher
-    )
+    CDPluginServices *cdsrv, const std::string& useragent, std::string& url,
+    const std::unordered_map<std::string, std::string>& querymap, std::unique_ptr<NetFetch>& fetcher)
 {
     LOGDEB("PlgWithSlave::translateurl: url " << url << "\n");
 
-    PlgWithSlave *realplg = dynamic_cast<PlgWithSlave*>(cdsrv->getpluginforpath(url));
+    CDPlugin *plg = cdsrv->getpluginforpath(url);
+    if (nullptr == plg) {
+        LOGERR("PlgWithSlave::translateurl: no plugin for path ["<< url << "\n");
+        return StreamProxy::Error;
+    }
+    PlgWithSlave *realplg = dynamic_cast<PlgWithSlave*>(plg);
     if (nullptr == realplg) {
-        LOGERR("PlgWithSlave::translateurl: no plugin for path ["<<url<< "\n");
+        LOGERR("PlgWithSlave::translateurl: bad plugin for path ["<< url << "\n");
         return StreamProxy::Error;
     }
 
     string path(url);
-
-    // The streaming services plugins set a trackId parameter in the
-    // URIs. This gets parsed out by mhttpd. We rebuild a full url
-    // which we pass to them for translation (they will extract the
-    // trackid and use it, the rest of the path is bogus).
-    // The uprcl module has a real path and no trackid. Handle both cases
-    const auto it = querymap.find("trackId");
-    if (it != querymap.end() && !it->second.empty()) {
-        path += string("/version/1/trackId/") + it->second;
-    }
-
     // Translate to Tidal/Qobuz etc real temporary URL
     url = realplg->get_media_url(path, useragent);
     if (url.empty()) {
